<?php

namespace Modules\St\Http\Controllers;

use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Modules\St\Entities\Module;
use Modules\St\Entities\ModulePermission;
use Modules\St\Entities\Permission;
use Modules\St\Entities\RoleModule;

class PermissionController extends Controller
{
    /**
     * Display a listing of the resource.
     * @return Renderable
     */
    public function index()
    {
        return view('st::index');
    }

    /**
     * Show the form for creating a new resource.
     * @return Renderable
     */
    public function create()
    {
        return view('st::create');
    }

    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Renderable
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Show the specified resource.
     * @param int $id
     * @return Renderable
     */
    public function show($id)
    {
        return view('st::show');
    }

    /**
     * Show the form for editing the specified resource.
     * @param int $id
     * @return Renderable
     */
    public function edit($id)
    {
        return view('st::edit');
    }

    /**
     * Update the specified resource in storage.
     * @param Request $request
     * @param int $id
     * @return Renderable
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     * @param int $id
     * @return Renderable
     */
    public function destroy($id)
    {
        //
    }



    public function allModule()
    {
        try {
            $modules =  Module::all();
            $responseBody = $this->responseBody(true, "Permission", "allModule", $modules);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "Permission", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }




    public function savePermission(Request $request)
    {
        try {
            $permission = new Permission();
            //$permission->module_id = $request->get('module');
            $permission->name = $request->get('permission');
            $permission->slug = $request->get('slug');
            //$permission->status = true;
            $save = $permission->save();

            if ($save) {
                $module_permission = new ModulePermission();
                $module_permission->module_id = $request->get('module');
                $module_permission->permission_id = $permission->id;
                $module_permission->save();
                $responseBody = $this->responseBody(true, "Permission", "saved", null);
            } else {
                $responseBody = $this->responseBody(false, "Permission", "saved", $save);
            }
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "Permission", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }




    public function allPermission()
    {
        try {
            $permissions =  Permission::all();
            $responseBody = $this->responseBody(true, "Permission", "allPermission", $permissions);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "Permission", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }



    public function deletePermission($id)
    {
        try {
            $permission = Permission::find($id);
            $delete = $permission->delete();
            if ($delete) {
                $responseBody = $this->responseBody(true, "Permission", "deleted", null);
            } else {
                $responseBody = $this->responseBody(false, "Permission", "saved", $delete);
            }
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "UserRole", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }




    public function getPermission($id)
    {
        $permission = Permission::find($id);
        return response()->json(["data" =>  $this->responseBody(true, "Permission", "getPermission", $permission)]);
    }


    public function updatePermission(Request $request, $id)
    {
        try {
            $permission = Permission::find($id);
            $permission->module_id = $request->get('module');
            $permission->name = $request->get('permission');
            $permission->slug = $request->get('slug');
            $permission->status = true;
            $save = $permission->save();
            if ($save) {
                $responseBody = $this->responseBody(true, "Permission", "updated", null);
            } else {
                $responseBody = $this->responseBody(false, "Permission", "updated", $save);
            }
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "Permission", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }




    /**
     * responseBody
     * This is used to create response.
     * @param success This is the paramter require boolean
     * @param name This is the paramter require ui table name
     * @param message This is the paramter require message content
     * @param result This is the paramter require result as some of data to return client
     * @return Json This returns as response.
     */
    private function responseBody($success, $name, $message, $result)
    {
        $body = [
            "success" => $success,
            "message" => $message,
            "name" => $name,
            "result" => $result
        ];
        return $body;
    }
}
